@@ -67,7 +67,8 @@ SUPPORTED_LANGUAGES = "en,fr,de,nl,es,pt,it,zh,ar,hi,ur,fa,ru"
 
 
 class TextRankSummarizerFormatter(FormatterBase, ProcessorBase, ABC):
-    """A graphbased ranking model for text processing. Extractive sentence summarization.
+    __doc__ = """A graphbased ranking model for text processing. Extractive sentence summarization.
+    #need-segments
     #languages:""" + SUPPORTED_LANGUAGES
 
     # cache_dir = os.path.join(xdg_cache_home, 'trankit')
